@@ -20,7 +20,7 @@ class ModelIterable(BaseIterable):
             kwargs['limit'] = slicing.stop
         result = db.execute(query, method, **kwargs)
         for item in result:
-            yield(self.queryset.model(item))
+            yield (self.queryset.model(item))
 
 
 class ValuesIterable(BaseIterable):
@@ -40,8 +40,9 @@ class ValuesIterable(BaseIterable):
 
 
 class QuerySet:
-    def __init__(self, model, method=None, query=None, slicing=None, iter_class=None, projection=None):
+    def __init__(self, model, db=None, method=None, query=None, slicing=None, iter_class=None, projection=None):
         self.model = model
+        self.db = db or model.db
         self.method = method
         self.slicing = slicing
         self.projection = projection
@@ -49,10 +50,6 @@ class QuerySet:
         self._cached_result = None
         self._iter_class = iter_class or ModelIterable
 
-    @property
-    def db(self):
-        return self.model.db
-
     @property
     def query(self):
         return self._query
@@ -75,6 +72,10 @@ class QuerySet:
     def __len__(self):
         return self.count()
 
+    def __bool__(self):
+        self._fetch_all()
+        return bool(self._cached_result)
+
     def _make_query(self, *query, **kwargs):
         kwargs_q = operators.AND(**kwargs)
         query_queue = [*query, kwargs_q]
@@ -87,7 +88,13 @@ class QuerySet:
         if not method:
             method = self.method
         queryset = self.__class__(
-            self.model, method=method, query=query, iter_class=iter_class, slicing=slicing, projection=projection)
+            self.model,
+            db=self.db,
+            method=method,
+            query=query,
+            iter_class=iter_class,
+            slicing=slicing,
+            projection=projection)
         return queryset
 
     def filter(self, *query, **kwargs):
@@ -125,13 +132,13 @@ class QuerySet:
 
     def all(self):
         if self.query:
-            raise expcetions.QueryError(
+            raise exceptions.QueryError(
                 'queryset does not support all() after first query')
         return self._clone(operators.EMPTY(), db.FILTER)
 
     def delete(self):
         if self.query:
-            raise expcetions.QueryError(
+            raise exceptions.QueryError(
                 'queryset does not support delete() before first query')
 
         return self.db.execute(self.query, db.BATCH_DELETE)
